@@ -1,5 +1,5 @@
-"""Entrypoint to make relevant classes available at the top level"""
+"""Entrypoint to make relevant classes available at the top level."""
 from .youconfigme import AutoConfig, Config, ConfigItemNotFound, ConfigSection
 
-__version__ = '0.3.0'
+__version__ = '0.6.7'
 __all__ = ['AutoConfig', 'Config', 'ConfigItemNotFound', 'ConfigSection']
